/*
 * Copyright (c) 2007, to-do. All rights reserved.
 */
static ex_proc op2ex[] = {
NULL,
ex_void,
NULL,
NULL,
NULL,
NULL,
NULL,
NULL,
NULL,
NULL,
NULL,
NULL,
NULL,
NULL,
NULL,
NULL,
ex_inc,
ex_dec,
ex_echo,
ex_doc,
NULL,
NULL,
NULL,
NULL,
NULL,
NULL,
NULL,
NULL,
NULL,
NULL,
NULL,
NULL,
ex_in,
ex_not,
ex_string,
NULL,
ex_case,
ex_mod,
ex_bitand,
ex_char,
NULL,
NULL,
ex_mul,
ex_add,
NULL,
ex_sub,
ex_join,
ex_div,
ex_catch,
ex_throw,
ex_return,
ex_exit,
ex_goto,
NULL,
NULL,
ex_var,
ex_label,
ex_function,
NULL,
NULL,
ex_lt,
ex_store,
ex_gt,
NULL,
ex_class,
ex_file,
ex_line,
ex_names,
ex_stdin,
ex_stdout,
ex_stderr,
ex_tmpout,
ex_tmperr,
ex_frameIn,
ex_frameOut,
ex_jump,
ex_load,
ex_copy,
ex_sand,
ex_pop,
ex_call,
ex_args,
ex_array,
ex_object,
ex_loop,
ex_plus,
ex_minus,
ex_bitnot,
ex_toBool,
ex_toChar,
ex_toInt,
NULL,
ex_toFloat,
NULL,
ex_bitxor,
ex_toString,
ex_regex,
ex_toNumber,
ex_typeof,
ex_delete,
ex_new,
ex_null,
ex_true,
ex_false,
ex_this,
ex_symbol,
ex_int,
ex_float,
ex_match,
ex_notmatch,
ex_and,
ex_or,
ex_eq,
ex_ne,
ex_cmp,
ex_bitshL,
ex_bitshR,
ex_pow,
NULL,
NULL,
NULL,
NULL,
NULL,
NULL,
ex_bitor,
NULL,
ex_bitsub,
NULL
};

